summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/object_factory.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/object_factory.h')
-rw-r--r--umbrello/umbrello/object_factory.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/umbrello/umbrello/object_factory.h b/umbrello/umbrello/object_factory.h
index 69338203..4c178ba4 100644
--- a/umbrello/umbrello/object_factory.h
+++ b/umbrello/umbrello/object_factory.h
@@ -31,7 +31,7 @@ namespace Object_Factory {
* @param n A name to give to the object (optional.)
* If not given then an input dialog prompts
* the user to supply a name.
- * @param parentPkg The object's tqparent package.
+ * @param parentPkg The object's parent package.
* @param solicitNewName Ask user for a different name if an object
* of the given name already exists.
* If set to false and the name already exists
@@ -45,18 +45,18 @@ UMLObject* createUMLObject(Uml::Object_Type type,
/**
* Creates an operation, attribute, template, or enum literal
* for the tqparent classifier.
*
* @param tqparent The tqparent concept
* @param type The type to create
* @return Pointer to the UMLClassifierListItem created
*/
-UMLClassifierListItem* createChildObject(UMLClassifier *tqparent, Uml::Object_Type type);
+UMLClassifierListItem* createChildObject(UMLClassifier *parent, Uml::Object_Type type);
-UMLAttribute *createAttribute(UMLObject *tqparent, const TQString& name,
+UMLAttribute *createAttribute(UMLObject *parent, const TQString& name,
UMLObject *type = 0);
-UMLOperation *createOperation(UMLClassifier *tqparent, const TQString& name);
+UMLOperation *createOperation(UMLClassifier *parent, const TQString& name);
/**
* Control whether the createUMLObject() solicits a new unique ID for the
@@ -45,18 +45,18 @@ UMLObject* createUMLObject(Uml::Object_Type type,
/**
* Creates an operation, attribute, template, or enum literal
- * for the tqparent classifier.
+ * for the parent classifier.
*
@@ -45,18 +45,18 @@ UMLObject* createUMLObject(Uml::Object_Type type,
*
- * @param tqparent The tqparent concept
+ * @param parent The parent concept
* @param type The type to create
* @return Pointer to the UMLClassifierListItem created